@@ -1,7 +1,6 @@
-use std::{io::Error, os::unix::process::CommandExt, process::Command};
+use std::{os::unix::process::CommandExt, process::Command};
 
 use crate::{builder::CommandGroupBuilder, GroupChild};
-use nix::unistd::setsid;
 
 impl CommandGroupBuilder<'_, Command> {
 	/// Executes the command as a child process group, returning a handle to it.
@@ -20,15 +19,10 @@ impl CommandGroupBuilder<'_, Command> {
 	///
 	/// Command::new("ls")
 	///         .group()
-	/// 		.spawn()
+	///         .spawn()
 	///         .expect("ls command failed to start");
 	/// ```
 	pub fn spawn(&mut self) -> std::io::Result<GroupChild> {
-		unsafe {
-			self.command
-				.pre_exec(|| setsid().map_err(Error::from).map(|_| ()));
-		}
-
-		self.command.spawn().map(GroupChild::new)
+		self.command.process_group(0).spawn().map(GroupChild::new)
 	}
 }
